@@ -1,6 +1,6 @@
 # ArgentinAPI - Access Argentinian Data via APIs and Curated Datasets
-# Version 0.2.0
-# Copyright (C) 2025 Renzo Caceres Rossi
+# Version 0.2.1
+# Copyright (C) 2026 Renzo Caceres Rossi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #'   \item \code{inicio}: Start date of the legal period (Date).
 #'   \item \code{fin}: End date of the legal period (Date).
 #' }
+#' Returns \code{NULL} if the API is unavailable or returns an error.
 #'
 #' @details
 #' The function parses the nested JSON structure returned by the API, extracts the period data,
@@ -60,7 +61,16 @@
 get_argentine_senators <- function() {
   url <- "https://api.argentinadatos.com/v1/senado/senadores"
 
-  res <- httr::GET(url)
+  res <- tryCatch({
+    httr::GET(url)
+  }, error = function(e) {
+    message(paste("Failed to connect to API:", e$message))
+    return(NULL)
+  })
+
+  if (is.null(res)) {
+    return(NULL)
+  }
 
   if (res$status_code != 200) {
     message(paste("Error: Received status code", res$status_code))
