@@ -1,6 +1,6 @@
 # ArgentinAPI - Access Argentinian Data via APIs and Curated Datasets
-# Version 0.2.0
-# Copyright (C) 2025 Renzo Caceres Rossi
+# Version 0.2.1
+# Copyright (C) 2026 Renzo Caceres Rossi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #' \url{https://api.argentinadatos.com/v1/feriados/2024/}
 #' If no year is provided, the function returns holidays for the current year.
 #'
-#' @param year An integer representing the year (between 2016 and 2025). Defaults to the current year.
+#' @param year An integer representing the year (between 2016 and current year). Defaults to the current year.
 #'
 #' @return A data frame with the following columns:
 #' \itemize{
@@ -31,11 +31,12 @@
 #'   \item \code{tipo}: Type of holiday (e.g., "inamovible", "trasladable").
 #'   \item \code{nombre}: Name or reason of the holiday.
 #' }
+#' Returns \code{NULL} if the API is unavailable or returns an error.
 #'
 #' @details
 #' The function sends a GET request to the ArgentinaDatos API and converts the JSON response into a structured
 #' data frame. It validates the input year and falls back to the current year if none is specified.
-#' If the API does not return a 200 status code, the function will return \code{NULL} and emit a message.
+#' If the API does not return a 200 status code or is unavailable, the function will return \code{NULL} and emit a message.
 #'
 #' @examples
 #' \dontrun{
@@ -65,14 +66,23 @@ get_argentinian_holidays <- function(year = NULL) {
   if (is.null(year)) {
     year <- lubridate::year(Sys.Date())
   }
-
-  if (!is.numeric(year) || year < 2016 || year > 2025) {
-    stop("Year must be an integer between 2016 and 2025.")
+  current_year <- lubridate::year(Sys.Date())
+  if (!is.numeric(year) || year < 2016 || year > current_year) {
+    warning(sprintf("Year must be an integer between 2016 and %d.", current_year))
+    return(NULL)
   }
-
   url <- paste0("https://api.argentinadatos.com/v1/feriados/", year)
 
-  res <- httr::GET(url)
+  res <- tryCatch({
+    httr::GET(url)
+  }, error = function(e) {
+    message(paste("Failed to connect to API:", e$message))
+    return(NULL)
+  })
+
+  if (is.null(res)) {
+    return(NULL)
+  }
 
   if (res$status_code != 200) {
     message(paste("Error: Received status code", res$status_code))
@@ -80,8 +90,6 @@ get_argentinian_holidays <- function(year = NULL) {
   }
 
   res_content <- jsonlite::fromJSON(httr::content(res, "text", encoding = "UTF-8"), flatten = TRUE)
-
   df <- dplyr::as_tibble(res_content)
-
   return(df)
 }
